#!/bin/ksh

# Returns 
# 0 if success
# 1 if rearm failed
# 2 if start Watchdog failed
# 3 if error

SUCCESS=0
REARM_FAILED=1
START_WD_FAILED=2
ERROR=3

MAX_RETRY=3
RETRY_REARM=0
RETRY_START=0

# verify is environment is set
if [ -z "$CANDLEHOME" ] ; then
   echo \$CANDLEHOME not defined
   exit $ERROR
fi

if [ -z "$COMMAND" ] ; then
   echo "Usage: $CANDLEHOME/bin/itmcmd execute [ -h install_dir ] pc rearmWatchdog.sh"
   exit $ERROR
fi

LOGFILE=$CANDLEHOME/logs/kcawd_rearmWatchdog.log

if [ "$COMMAND" = "klzagent" ] ; then
   PC=lz
elif [ "$COMMAND" = "kuxagent" ] ; then
   PC=ux
else
   echo "Watchdog not present for agent $COMMAND"
   exit $ERROR
fi

# start the Watchdog 
WD_DIR=`dirname $0`
while [ $RETRY_START != $MAX_RETRY ]
do
   RETRY_START=`expr $RETRY_START + 1`
   $WD_DIR/startWatchdog.sh
   # success if running(0) or already running(1)
   if [ $? = 0 -o $? = 1 ] ; then 
      break 
   fi  
done

if [ $RETRY_START = $MAX_RETRY ] ; then
   # unable to start watchdog process
   echo Failed to rearm Watchdog: Watchdog could not be started.
   exit $START_WD_FAILED;
fi

# send rearm
while [ $RETRY_REARM != $MAX_RETRY ]
do
   RETRY_REARM=`expr $RETRY_REARM + 1`
   # Get the agent process pid using cinfo
   OSAGT_PID=`$CANDLEHOME/bin/cinfo -R | grep -w $PC | grep "\.running" | awk '{print $3}'`
   echo "OSAGT_PID = " $OSAGT_PID > $LOGFILE

   # if agent is running
   if [ -n "$OSAGT_PID" ] ; then 
      # OSAGT_PID can be a list, check all pids to be sure process is the OSAgent before sending signal
      for PID in `echo $OSAGT_PID` 
      do
          # check if running process has same CANDLEHOME and is the OSAgent (klzagent or kuxagent)
          IS_OSAGENT=`ps -fp $PID | grep $COMMAND | grep $CANDLEHOME`
          if [ -n "$IS_OSAGENT" ] ; then
              # Save command to log file
	      echo "Sending -USR2 " $PID "(" $IS_OSAGENT ")"  >> $LOGFILE
              # send SIGUSR2 to the OSAgent
	      kill -USR2 $PID
	      if [ $? = 0 ] ; then
                  # break both loops (for 'pid' & while 'retry')
		  break 2
	      fi
	  fi
      done 
   else
      # agent is not running - nothing to do
      break
   fi
done

if [ $RETRY_REARM = $MAX_RETRY ] ; then
   # unable to send USR2 signal
   echo Failed to rearm Watchdog: $COMMAND agent did not respond to request.
   exit $REARM_FAILED;
fi

echo Watchdog successfully rearmed
exit $SUCCESS

