#!/bin/ksh
# Returns 
# 0 if success
# 1 if disarm failed
# 2 if stop Watchdog failed
# 3 if error

SUCCESS=0
DISARM_FAILED=1
STOP_WD_FAILED=2
ERROR=3

MAX_RETRY=3
RETRY_DISARM=0
RETRY_STOP=0

THIS_DIR=`dirname $0`
KCAWD_DISABLE_STOP_FILE=$THIS_DIR/.kcawd_disable_stop

# verify is environment is set
if [ -z "$CANDLEHOME" ] ; then
   echo \$CANDLEHOME not defined
   exit $ERROR
fi

if [ -z "$COMMAND" ] ; then
   echo "Usage: $CANDLEHOME/bin/itmcmd execute [ -h install_dir ] pc disarmWatchdog.sh"
   exit $ERROR
fi

LOGFILE=$CANDLEHOME/logs/kcawd_disarmWatchdog.log

if [ "$COMMAND" = "klzagent" ] ; then
   PC=lz
elif [ "$COMMAND" = "kuxagent" ] ; then
   PC=ux
else
   echo "Watchdog not present for agent $COMMAND"
   exit $ERROR
fi

while [ $RETRY_DISARM != $MAX_RETRY ]
do
   RETRY_DISARM=`expr $RETRY_DISARM + 1`
   # Get the agent process pid using cinfo (cinfo call is not globalized by default - look for running processes)
   OSAGT_PID=`$CANDLEHOME/bin/cinfo -R | grep -w $PC | grep "\.running" | awk '{print $3}'`
   echo "OSAGT_PID = " $OSAGT_PID > $LOGFILE
   
   # if agent is running
   if [ -n "$OSAGT_PID" ] ; then 
      # OSAGT_PID can be a list, check all pids to be sure process is the OSAgent before sending signal
      for PID in `echo $OSAGT_PID` 
      do
          # check if running process has same CANDLEHOME and is the OSAgent (klzagent or kuxagent)
          IS_OSAGENT=`ps -fp $PID | grep $COMMAND | grep $CANDLEHOME`
          if [ -n "$IS_OSAGENT" ] ; then
              # send SIGUSR1 to the OSAgent
	      # Save command to log file
	       echo "Sending -USR1 " $PID "(" $IS_OSAGENT ")"  >> $LOGFILE
	      kill -USR1 $PID
	      if [ $? = 0 ] ; then
                  # break both loops (for 'pid' & while 'retry')
		  break 2
	      fi
	  fi
      done 
   else
      # agent is not running - nothing to do
      break
   fi
done

if [ $RETRY_DISARM = $MAX_RETRY ] ; then
   # unable to send USR1 signal
   echo Failed to disarm Watchdog: $COMMAND agent did not respond to request.
   exit $DISARM_FAILED
fi

# verify presence of control file
if [ ! -f $KCAWD_DISABLE_STOP_FILE ] ; then
  # stop the Watchdog 
  WD_DIR=`dirname $0`
  echo "Calling stopWatchdog"  >> $LOGFILE
  while [ $RETRY_STOP != $MAX_RETRY ]
  do
     RETRY_STOP=`expr $RETRY_STOP + 1`
     $WD_DIR/stopWatchdog.sh
     # success if stopped(0) or already stopped(1)
     if [ $? = 0 -o $? = 1 ] ; then 
        break 
     fi  
  done
fi

if [ $RETRY_STOP = $MAX_RETRY ] ; then
   # unable to stop watchdog process
   echo "Failed to disarm Watchdog: Watchdog could not be stopped." >> $LOGFILE
   echo Failed to disarm Watchdog: Watchdog could not be stopped.
   exit $STOP_WD_FAILED
fi

echo Watchdog successfully disarmed
exit $SUCCESS
