#!/bin/ksh

# Returns 
# 0 if stopped successfully
# 1 if already stopped
# 3 if error

STOPPED=0
ALREADY_STOPPED=1
ERROR=3

STATUS_STOPPED=1

# Get the kcawd path
WD_DIR=`dirname $0`
RET_CODE=$ERROR
LOGFILE=$WD_DIR/../../../logs/kcawd_stopWatchdog.log

# Check if kcawd status
# Verifies process is kcawd in our CANDLEHOME and if zones, current zone
$WD_DIR/statusWatchdog.sh
WD_STATUS=$?

echo "statusWatchdog RC = " $WD_STATUS > $LOGFILE

if [ $WD_STATUS = $STATUS_STOPPED ] ; then
   RET_CODE=$ALREADY_STOPPED
else
   SIG=TERM
   MAX_RETRY=3
   RETRY=0
   while [ $WD_STATUS != $STATUS_STOPPED ]
   do
      # Get the current pid from kcawd.pid file
      WD_PID=`cat $WD_DIR/kcawd.pid 2>/dev/null`

      # Last call to statusWatchdog updated kcawd.pid file
      # If no PID or less than 1 leave
      if [[ ( -z "$WD_PID" ) || ( $WD_PID -le 1 ) ]] ; then
         break
      fi

      # Stop kcawd sending a SIGTERM or SIGKILL
      LOG_PID=`ps -fp $WD_PID | grep kcawd`
      echo "Sending " $SIG $WD_PID "(" $LOG_PID ")" >> $LOGFILE
      kill -$SIG $WD_PID

      # Wait for kcawd process to end
      sleep 1

      # Verify if kcawd is down
      $WD_DIR/statusWatchdog.sh
      WD_STATUS=$?
      # If still running after retry, force to kill
      if [ $RETRY = 1 ] ; then
         SIG=KILL
      fi
      RETRY=`expr $RETRY + 1`
      if [ $RETRY -ge $MAX_RETRY ] ; then
           break
      fi
   done

   RET_CODE=$STOPPED
   # Delete the kcawd.pid file
   rm $WD_DIR/kcawd.pid >/dev/null 2>&1
fi

exit $RET_CODE
