#!/bin/ksh

# Returns 
# 0 if "RUNNING" 
# 1 if "STOPPED"

RUNNING="RUNNING"
STOPPED="STOPPED"

# Get the kcawd path
THIS_DIR=`dirname $0`
PC="lz"
if [ -f "$THIS_DIR/kuxagent" ] ; then
   PC="ux"
fi

WD_DIR=$CANDLEHOME/$ITM_BINARCH/$PC/bin

IS_SLASH=`echo "$CANDLEHOME" | awk '{print substr($0,length($0),1)}'`

if [ x"$IS_SLASH" = x"/" ] ; then
   CANDLEHOME_SLASH="$CANDLEHOME"
else
   CANDLEHOME_SLASH="$CANDLEHOME/"
fi

# Get the current pid from kcawd.pid file
WD_PID=`cat $WD_DIR/kcawd.pid 2>/dev/null`

# verify process is running
RET_CODE=0
WD_STATUS=$RUNNING

# dont use pgrep to get oldest process running (if multiple processes) -- use candle home instead
# WD_PROC_PID=`pgrep -o $WD_DIR/kcawd 2>/dev/null`
# if pgrep is not available, use ps


# Check if running on Solaris and if so if running on in a Global Zone.
GLOBAL_ZONE=0
IS_SOLARIS=`echo $ITM_BINARCH | grep "^sol"`
if [ -n "$IS_SOLARIS" ] ; then
   if [ -f /usr/bin/zonename ] ; then
      # In Zones environment
      ZONENAME=`/usr/bin/zonename`
      if [ x"$ZONENAME" = x"global" ]; then
         GLOBAL_ZONE=1
      fi
   fi
fi

if [ $GLOBAL_ZONE -eq 1 ] ; then
   WD_PROC_PID=`ps -fz global | grep kcawd | grep $CANDLEHOME_SLASH | grep -v "grep kcawd" | awk '{print $2}'`
else
   WD_PROC_PID=`ps -ef | grep kcawd | grep $CANDLEHOME_SLASH | grep -v "grep kcawd" | awk '{print $2}'`
fi 

if [ -z "$WD_PROC_PID" ] ; then
   WD_STATUS=$STOPPED
   RET_CODE=1
   # remove kcawd.pid
   rm $WD_DIR/kcawd.pid > /dev/null 2>&1
elif [ "$WD_PROC_PID" != "$WD_PID" ] ; then
   # update kcawd.pid file
   echo $WD_PROC_PID > $WD_DIR/kcawd.pid
fi
 
echo $WD_STATUS

exit $RET_CODE
